==> zio-aws-schemas_2.13-5.17.130.3-sources.jar: zio/aws/schemas/model/DeleteDiscovererRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteDiscovererRequest(discovererId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest = {
    import DeleteDiscovererRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest
      .builder()
      .discovererId(__string.unwrap(discovererId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.DeleteDiscovererRequest.ReadOnly =
    zio.aws.schemas.model.DeleteDiscovererRequest.wrap(buildAwsValue())
}
object DeleteDiscovererRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.DeleteDiscovererRequest =
      zio.aws.schemas.model.DeleteDiscovererRequest(discovererId)
    def discovererId: __string
    def getDiscovererId: ZIO[Any, Nothing, __string] = ZIO.succeed(discovererId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest
  ) extends zio.aws.schemas.model.DeleteDiscovererRequest.ReadOnly {
    override val discovererId: __string =
      zio.aws.schemas.model.primitives.__string(impl.discovererId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest
  ): zio.aws.schemas.model.DeleteDiscovererRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-schemas_2.13-5.20.42.1-sources.jar: zio/aws/schemas/model/DeleteDiscovererRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteDiscovererRequest(discovererId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest = {
    import DeleteDiscovererRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest
      .builder()
      .discovererId(discovererId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.DeleteDiscovererRequest.ReadOnly =
    zio.aws.schemas.model.DeleteDiscovererRequest.wrap(buildAwsValue())
}
object DeleteDiscovererRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.DeleteDiscovererRequest =
      zio.aws.schemas.model.DeleteDiscovererRequest(discovererId)
    def discovererId: __string
    def getDiscovererId: ZIO[Any, Nothing, __string] = ZIO.succeed(discovererId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest
  ) extends zio.aws.schemas.model.DeleteDiscovererRequest.ReadOnly {
    override val discovererId: __string = impl.discovererId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.DeleteDiscovererRequest
  ): zio.aws.schemas.model.DeleteDiscovererRequest.ReadOnly = new Wrapper(impl)
}
